4.32. umbra.managers.fileSystemEventsManager — Umbra 1.0.4 documentation

### Navigation

- index
- modules |
- next |
- previous |
- Umbra 1.0.4 documentation »
- 4. Api »

# 4.32. umbra.managers.fileSystemEventsManager

fileSystemEventsManager.py

Platform:
  Windows, Linux, Mac Os X.
Description:
  This module defines the `FileSystemEventsManager` class.

Others:

## 4.32.1. Module Attributes

`umbra.managers.fileSystemEventsManager.` `LOGGER`

## 4.32.2. Classes

class `umbra.managers.fileSystemEventsManager.` `FileSystemEventsManager`(parent=None)

  Bases: `PyQt4.QtCore.QThread`

  This class defines the file system events manager.

  `fileChanged`

    This signal is emited by the `FileSystemEventsManager` class when a file is changed. ( pyqtSignal )

    Returns: | Current changed file. ( String )

  `fileInvalidated`

    This signal is emited by the `FileSystemEventsManager` class when a file is invalidated. ( pyqtSignal )

    Returns: | Current invalidated file. ( String )

  `directoryChanged`

    This signal is emited by the `FileSystemEventsManager` class when a directory is changed. ( pyqtSignal )

    Returns: | Current changed directory. ( String )

  `directoryInvalidated`

    This signal is emited by the `FileSystemEventsManager` class when a directory is invalidated. ( pyqtSignal )

    Returns: | Current invalidated directory. ( String )

  `container`

    This method is the property for self.__container attribute.

    Returns: | self.__container. ( QObject )

  `paths`

    This method is the property for self.__paths attribute.

    Returns: | self.__paths. ( Dictionary )

  `timer`

    This method is the property for self.__timer attribute.

    Returns: | self.__timer. ( QTimer )

  `timerCycleMultiplier`

    This method is the property for self.__timerCycleMultiplier attribute.

    Returns: | self.__timerCycleMultiplier. ( Float )

  `run`()

    This method reimplements the `QThread.run()` method.

  `listPaths`()

    This method returns the registered paths.

    Returns: | Registered paths. ( List )

  `isPathRegistered`(path)

    This method returns if the given path is registered.

    Parameters: | path – Path name. ( String )
    Returns: | Is path registered. ( Boolean )

  `registerPath`(path, modifiedTime=None)

    This method registers given path.

    Parameters: | path – Path name. ( String ) modifiedTime – Custom modified time. ( Integer / Float )
    Returns: | Method success. ( Boolean )

  `unregisterPath`(path)

    This method unregisters given path.

    Parameters: | path – Path name. ( String )
    Returns: | Method success. ( Boolean )

### Navigation

- index
- modules |
- next |
- previous |
- Umbra 1.0.4 documentation »
- 4. Api »